Index: third_party/WebKit/Source/core/editing/EditingStrategy.cpp |
diff --git a/third_party/WebKit/Source/core/editing/EditingStrategy.cpp b/third_party/WebKit/Source/core/editing/EditingStrategy.cpp |
index cdf3200f2de24ea378895fe9fe210cfe2e197ba3..742fbb42ded5c405170d72f08023e1be1d62c437 100644 |
--- a/third_party/WebKit/Source/core/editing/EditingStrategy.cpp |
+++ b/third_party/WebKit/Source/core/editing/EditingStrategy.cpp |
@@ -27,10 +27,10 @@ int EditingAlgorithm<Traversal>::caretMaxOffset(const Node& node) |
template <typename Traversal> |
bool EditingAlgorithm<Traversal>::isEmptyNonEditableNodeInEditable(const Node* node) |
{ |
// Editability is defined the DOM tree rather than the composed tree. For example: |
// DOM: |
// <host><span>unedittable</span><shadowroot><div ce><content /></div></shadowroot></host> |
- // Composed Tree: |
+ // Flat Tree: |
// <host><div ce><span1>unedittable</span></div></host> |
// e.g. editing/shadow/breaking-editing-boundaries.html |
return !Traversal::hasChildren(*node) && !node->hasEditableStyle() && node->parentNode() && node->parentNode()->hasEditableStyle(); |
@@ -90,6 +90,6 @@ Node* EditingAlgorithm<Strategy>::rootUserSelectAllForNode(Node* node) |
} |
template class CORE_TEMPLATE_EXPORT EditingAlgorithm<NodeTraversal>; |
-template class CORE_TEMPLATE_EXPORT EditingAlgorithm<ComposedTreeTraversal>; |
+template class CORE_TEMPLATE_EXPORT EditingAlgorithm<FlatTreeTraversal>; |
} // namespace blink |
@@ -27,10 +27,10 @@ int EditingAlgorithm<Traversal>::caretMaxOffset(const Node& node) |
bool EditingAlgorithm<Traversal>::isEmptyNonEditableNodeInEditable(const Node* node) |
{ |
- // Editability is defined the DOM tree rather than the composed tree. For example: |
+ // Editability is defined the DOM tree rather than the flat tree. For example: |
// DOM: |
// <host><span>unedittable</span><shadowroot><div ce><content /></div></shadowroot></host> |